Learn R Programming

binr (version 1.1.2)

bins.getvals: Extract Cut Points from Bins Object

Description

Extracts cut points from the object returned by bins. The cut points are always between the values in x and weighed such that the cut point splits the area under the line from (lo, n1) to (hi, n2) in half.

Usage

bins.getvals(lst, minpt = -Inf, maxpt = Inf)

Value

A vector of cut points extracted from the lst object. The actual low and high values in each bin, as well as the counts of values in each bin are placed in attributes binlo, binhi and binct, respectively.

Arguments

lst

The list returned by the bins function.

minpt

The value replacing the lower bound of the cut points.

maxpt

The value replacing the upper bound of the cut points.

See Also

bins