Cuts the data set x into roughly equal groups using quantiles
Because the number of unique values may be smaller than target.bins, the function gradually increases the number of quantiles up to max.breaks or until the target.bins number of bins is reached.
bins.quantiles(x, target.bins, max.breaks, verbose = FALSE)A numeric vector to be cut in bins.
Target number of bins, which may not be reached if the number of unique values is smaller than the specified value.
Maximum number of quantiles; must be at least as
large as target.bins.
Indicates verbose output.
binr, bins, bins.greedy, bins.optimize