Extracts cut points from the object returned by bins.
The cut points are always between the values in x and weighed such that
the cut point splits the area under the line from (lo, n1) to (hi, n2) in half.
bins.getvals(lst, minpt = -Inf, maxpt = Inf)A vector of cut points extracted from the
lst object. The actual low and high values in each bin, as well
as the counts of values in each bin are placed in attributes
binlo, binhi and binct, respectively.
The list returned by the bins function.
The value replacing the lower bound of the cut points.
The value replacing the upper bound of the cut points.
bins