bins.merr: Binning Error Function
Description
Partitioning the data into bins using splitting, merging
and moving optimizes this error function, which is the mean squared error
of point counts in the bins relative to the optimal number of points per bin.
Usage
bins.merr(binct, target.bins)
Value
The mean squared error.
Arguments
- binct
The number of points falling into the bins.
- target.bins
Number of bins desired; this is also the max number of bins.